blackdoc: apply black to code in documentation
==============================================

**blackdoc** extracts code from documentation, applies **black** to it
and, in reformatting mode, writes the formatted code back to the file.

The currently supported formats are:

- doctest
- ipython
- rst
- markdown

Documentation
-------------
**User Guide**

* :doc:`installing`
* :doc:`usage`
* :doc:`options`


.. toctree::
   :maxdepth: 1
   :caption: User Guide
   :hidden:

   installing
   usage
   options

**Help & Reference**

* :doc:`changelog`
* :doc:`contributing`


.. toctree::
   :maxdepth: 1
   :caption: Help & Reference
   :hidden:

   changelog
   contributing
